==> jc-1.4.0.tar.gz: javax/print/attribute/standard/JobStateReasons.h <==
// public final class javax.print.attribute.standard.JobStateReasons

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 8ea716c64b77f8eb java_util_AbstractCollection
// @dep_class ca427569b5b2f804 java_util_AbstractSet
// @dep_class 3c285c721478414d java_util_HashSet
// @dep_class 2db6fd4bc612181a javax_print_attribute_standard_JobStateReasons

// header file dependencies
// @dep_header java_util_HashSet

#include "java/util/HashSet.h"

#ifndef _JC_javax_print_attribute_standard_JobStateReasons_H_
#define _JC_javax_print_attribute_standard_JobStateReasons_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_javax_print_attribute_standard_JobStateReasons$sub_refs	_jc_javax_print_attribute_standard_JobStateReasons$sub_refs;
typedef struct _jc_javax_print_attribute_standard_JobStateReasons$sub_nonrefs	_jc_javax_print_attribute_standard_JobStateReasons$sub_nonrefs;
typedef struct _jc_javax_print_attribute_standard_JobStateReasons$refs	_jc_javax_print_attribute_standard_JobStateReasons$refs;
typedef struct _jc_javax_print_attribute_standard_JobStateReasons$nonrefs	_jc_javax_print_attribute_standard_JobStateReasons$nonrefs;
typedef struct _jc_javax_print_attribute_standard_JobStateReasons$object	_jc_javax_print_attribute_standard_JobStateReasons$object;

typedef struct _jc_javax_print_attribute_standard_JobStateReasons$fields_struct	_jc_javax_print_attribute_standard_JobStateReasons$fields_struct;
typedef const struct _jc_javax_print_attribute_standard_JobStateReasons$vmethods	_jc_javax_print_attribute_standard_JobStateReasons$vmethods;
typedef const struct _jc_javax_print_attribute_standard_JobStateReasons$vtable	_jc_javax_print_attribute_standard_JobStateReasons$vtable;
typedef const struct _jc_javax_print_attribute_standard_JobStateReasons$vtype	_jc_javax_print_attribute_standard_JobStateReasons$vtype;

// Class fields structure
struct _jc_javax_print_attribute_standard_JobStateReasons$fields_struct {
	struct _jc_java_lang_Class$object	*class__24javax__24print__24attribute__24standard__24JobStateReasons;
	jlong	serialVersionUID;
};
extern _jc_javax_print_attribute_standard_JobStateReasons$fields_struct _jc_javax_print_attribute_standard_JobStateReasons$class_fields;

// Constructors
extern void _jc_javax_print_attribute_standard_JobStateReasons$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_print_attribute_standard_JobStateReasons$object *);

// Virtual methods
extern struct _jc_java_lang_Class$object *_jc_javax_print_attribute_standard_JobStateReasons$method$getCategory$1a83ac042894bcc8(_jc_env *, struct _jc_javax_print_attribute_standard_JobStateReasons$object *);
extern struct _jc_java_lang_String$object *_jc_javax_print_attribute_standard_JobStateReasons$method$getName$bec186f2ce7e1882(_jc_env *, struct _jc_javax_print_attribute_standard_JobStateReasons$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_print_attribute_standard_JobStateReasons$method_info$getCategory$1a83ac042894bcc8;
extern _jc_method _jc_javax_print_attribute_standard_JobStateReasons$method_info$getName$bec186f2ce7e1882;

// Static methods
extern struct _jc_java_lang_Class$object *_jc_javax_print_attribute_standard_JobStateReasons$method$class$c900dc17c9967b78(_jc_env *, struct _jc_java_lang_String$object *, jboolean);

// Virtual methods structure
struct _jc_javax_print_attribute_standard_JobStateReasons$vmethods {
	struct _jc_java_lang_Class$object	*(*getCategory$1a83ac042894bcc8)(_jc_env *, struct _jc_javax_print_attribute_standard_JobStateReasons$object *);
	struct _jc_java_lang_String$object	*(*getName$bec186f2ce7e1882)(_jc_env *, struct _jc_javax_print_attribute_standard_JobStateReasons$object *);
};

// Vtable
struct _jc_javax_print_attribute_standard_JobStateReasons$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_AbstractCollection$vmethods	java_util_AbstractCollection;
	_jc_java_util_AbstractSet$vmethods	java_util_AbstractSet;
	_jc_java_util_HashSet$vmethods	java_util_HashSet;
	_jc_javax_print_attribute_standard_JobStateReasons$vmethods	javax_print_attribute_standard_JobStateReasons;
};

// Vtype
struct _jc_javax_print_attribute_standard_JobStateReasons$vtype {
	_jc_type			type;
	_jc_javax_print_attribute_standard_JobStateReasons$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_print_attribute_standard_JobStateReasons$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_print_attribute_standard_JobStateReasons$refs {
    _jc_javax_print_attribute_standard_JobStateReasons$sub_refs	javax_print_attribute_standard_JobStateReasons;
    _jc_java_util_HashSet$sub_refs	java_util_HashSet;
    _jc_java_util_AbstractSet$sub_refs	java_util_AbstractSet;
    _jc_java_util_AbstractCollection$sub_refs	java_util_AbstractCollection;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_print_attribute_standard_JobStateReasons$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_print_attribute_standard_JobStateReasons$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_AbstractCollection$sub_nonrefs	java_util_AbstractCollection;
    _jc_java_util_AbstractSet$sub_nonrefs	java_util_AbstractSet;
    _jc_java_util_HashSet$sub_nonrefs	java_util_HashSet;
    _jc_javax_print_attribute_standard_JobStateReasons$sub_nonrefs	javax_print_attribute_standard_JobStateReasons;
};

// Object instance structure
struct _jc_javax_print_attribute_standard_JobStateReasons$object {
	_jc_javax_print_attribute_standard_JobStateReasons$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_print_attribute_standard_JobStateReasons$vtype	*vtype;
	_jc_javax_print_attribute_standard_JobStateReasons$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_print_attribute_standard_JobStateReasons$vtype _jc_javax_print_attribute_standard_JobStateReasons$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_print_attribute_standard_JobStateReasons, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_print_attribute_standard_JobStateReasons$class_object;

#endif	/* _JC_javax_print_attribute_standard_JobStateReasons_H_ */

==> jc-1.4.6.tar.gz: javax/print/attribute/standard/JobStateReasons.h <==
// public final class javax.print.attribute.standard.JobStateReasons

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 8ea716c64b77f8eb java_util_AbstractCollection
// @dep_class ca427569b5b2f804 java_util_AbstractSet
// @dep_class 3c285c721478414d java_util_HashSet
// @dep_class 2db6fd4bc612181a javax_print_attribute_standard_JobStateReasons

// header file dependencies
// @dep_header java_util_HashSet

#include "java/util/HashSet.h"

#ifndef _JC_javax_print_attribute_standard_JobStateReasons_H_
#define _JC_javax_print_attribute_standard_JobStateReasons_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_javax_print_attribute_standard_JobStateReasons$sub_refs	_jc_javax_print_attribute_standard_JobStateReasons$sub_refs;
typedef struct _jc_javax_print_attribute_standard_JobStateReasons$sub_nonrefs	_jc_javax_print_attribute_standard_JobStateReasons$sub_nonrefs;
typedef struct _jc_javax_print_attribute_standard_JobStateReasons$refs	_jc_javax_print_attribute_standard_JobStateReasons$refs;
typedef struct _jc_javax_print_attribute_standard_JobStateReasons$nonrefs	_jc_javax_print_attribute_standard_JobStateReasons$nonrefs;
typedef struct _jc_javax_print_attribute_standard_JobStateReasons$object	_jc_javax_print_attribute_standard_JobStateReasons$object;

typedef struct _jc_javax_print_attribute_standard_JobStateReasons$fields_struct	_jc_javax_print_attribute_standard_JobStateReasons$fields_struct;
typedef const struct _jc_javax_print_attribute_standard_JobStateReasons$vmethods	_jc_javax_print_attribute_standard_JobStateReasons$vmethods;
typedef const struct _jc_javax_print_attribute_standard_JobStateReasons$vtable	_jc_javax_print_attribute_standard_JobStateReasons$vtable;
typedef const struct _jc_javax_print_attribute_standard_JobStateReasons$vtype	_jc_javax_print_attribute_standard_JobStateReasons$vtype;

// Class fields structure
struct _jc_javax_print_attribute_standard_JobStateReasons$fields_struct {
	struct _jc_java_lang_Class$object	*class__24javax__24print__24attribute__24standard__24JobStateReasons;
	jlong	serialVersionUID;
};
extern _jc_javax_print_attribute_standard_JobStateReasons$fields_struct _jc_javax_print_attribute_standard_JobStateReasons$class_fields;

// Constructors
extern void _jc_javax_print_attribute_standard_JobStateReasons$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_print_attribute_standard_JobStateReasons$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_Class$object *_jc_javax_print_attribute_standard_JobStateReasons$method$getCategory$1a83ac042894bcc8(_jc_env *, struct _jc_javax_print_attribute_standard_JobStateReasons$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_javax_print_attribute_standard_JobStateReasons$method$getName$bec186f2ce7e1882(_jc_env *, struct _jc_javax_print_attribute_standard_JobStateReasons$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_print_attribute_standard_JobStateReasons$method_info$getCategory$1a83ac042894bcc8;
extern _jc_method _jc_javax_print_attribute_standard_JobStateReasons$method_info$getName$bec186f2ce7e1882;

// Static methods
extern struct _jc_java_lang_Class$object *_jc_javax_print_attribute_standard_JobStateReasons$method$class$c900dc17c9967b78(_jc_env *, struct _jc_java_lang_String$object *, jboolean) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_javax_print_attribute_standard_JobStateReasons$vmethods {
	struct _jc_java_lang_Class$object	*(*getCategory$1a83ac042894bcc8)(_jc_env *, struct _jc_javax_print_attribute_standard_JobStateReasons$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*getName$bec186f2ce7e1882)(_jc_env *, struct _jc_javax_print_attribute_standard_JobStateReasons$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_print_attribute_standard_JobStateReasons$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_AbstractCollection$vmethods	java_util_AbstractCollection;
	_jc_java_util_AbstractSet$vmethods	java_util_AbstractSet;
	_jc_java_util_HashSet$vmethods	java_util_HashSet;
	_jc_javax_print_attribute_standard_JobStateReasons$vmethods	javax_print_attribute_standard_JobStateReasons;
};

// Vtype
struct _jc_javax_print_attribute_standard_JobStateReasons$vtype {
	_jc_type			type;
	_jc_javax_print_attribute_standard_JobStateReasons$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_print_attribute_standard_JobStateReasons$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_print_attribute_standard_JobStateReasons$refs {
    _jc_javax_print_attribute_standard_JobStateReasons$sub_refs	javax_print_attribute_standard_JobStateReasons;
    _jc_java_util_HashSet$sub_refs	java_util_HashSet;
    _jc_java_util_AbstractSet$sub_refs	java_util_AbstractSet;
    _jc_java_util_AbstractCollection$sub_refs	java_util_AbstractCollection;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_print_attribute_standard_JobStateReasons$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_print_attribute_standard_JobStateReasons$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_AbstractCollection$sub_nonrefs	java_util_AbstractCollection;
    _jc_java_util_AbstractSet$sub_nonrefs	java_util_AbstractSet;
    _jc_java_util_HashSet$sub_nonrefs	java_util_HashSet;
    _jc_javax_print_attribute_standard_JobStateReasons$sub_nonrefs	javax_print_attribute_standard_JobStateReasons;
};

// Object instance structure
struct _jc_javax_print_attribute_standard_JobStateReasons$object {
	_jc_javax_print_attribute_standard_JobStateReasons$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_print_attribute_standard_JobStateReasons$vtype	*vtype;
	_jc_javax_print_attribute_standard_JobStateReasons$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_print_attribute_standard_JobStateReasons$vtype _jc_javax_print_attribute_standard_JobStateReasons$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_print_attribute_standard_JobStateReasons, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_print_attribute_standard_JobStateReasons$class_object;

#endif	/* _JC_javax_print_attribute_standard_JobStateReasons_H_ */
